#!/usr/bin/env python
# -*- coding: utf-8 -*-
from __future__ import with_statement
from __future__ import division
from __future__ import absolute_import


def test_assert():
    a = 1
    b = 1
    assert a == b
