{% import 'macros/actions.html' as actions_macros %}

{% macro list_actions(list_actions) -%}
    <div class="btn-group pull-right">
        {% for action_element in list_actions %}
            {{ actions_macros.action(action_element=action_element) }}
        {% endfor %}
    </div>
{%- endmacro %}